##  How to Implement 6R in SAP LeanIX
In SAP LeanIX, the 6R framework is represented as an attribute in the Application Fact Sheet type. This attribute allows users to classify each application into specific 6R categories. An outline of the process of implementing 6R in SAP LeanIX is as follows:
  * Determine the 6R classification of each application. It is a process that involves collaboration and considering various factors like technology needs, business impacts, and complexity of change.
  * 6R classification of the application is then documented in the Application Fact Sheet in the 6R attribute field.
  * Users then can use Reports and Diagrams to assess the application portfolio, which will help them identify opportunities for cloud migration and modernization initiatives. For more information, refer to [Application Modernization](https://help.sap.com/docs/leanix/ea/application-modernization?locale=en-US&state=PRODUCTION&version=CLOUD "SAP LeanIX offers a strategic approach to modernizing outdated application portfolios, helping organizations reduce technical debt and operational costs while enhancing agility and innovation. This guide is useful for understanding how to effectively plan and execute continuous transformation tailored to specific organizational needs.").


The details of these processes are further explained in the following sections.
But, to get started, you need to add the 6R classification attribute to your SAP LeanIX workspace. The process of adding the attribute is described in the next section.
